package
Version:
v1.0.0-alpha.7
Opens a new window with list of versions in this module.
Published: Feb 26, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Strikethrough converts `<strike>`, `<s>`, and `<del>` elements
func WithDelimiter(delimiter string) option
Source Files
¶
Click to show internal directories.
Click to hide internal directories.